==> thx_store-0.0.2-py3-none-any.whl: thx/store/models.py <==
# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from thx.address.models import Address, AddressCoordinate
from thx.core.models import UserModel, DateModel, StatusModel, OrderedModel, CleanModel


class Store(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        unique=True,
        max_length=50,
        verbose_name=_('code'),
    )
    name = models.CharField(
        unique=True,
        max_length=255,
        verbose_name=_('name'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )
    default = models.BooleanField(
        default=False,
        verbose_name=_('default'),
    )

    class Meta:
        verbose_name = _('store')
        verbose_name_plural = _('stores')
        ordering = ('ordering',)
        permissions = (
            ("list_store", "Can list store"),
            ("detail_store", "Can detail store"),
            ("enable_store", "Can enable store"),
            ("disable_store", "Can disable store"),
        )

    def __str__(self):
        return self.name


class StoreAddress(Address, AddressCoordinate, CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    # TODO: COMPLETE WITH ADDRESS
    store = models.OneToOneField(
        Store,
        related_name='address',
        on_delete=models.PROTECT,
    )

    class Meta:
        verbose_name = _('store address')
        verbose_name_plural = _('store addresses')
        ordering = ('ordering',)
        permissions = (
            ("list_storeaddress", "Can list store address"),
            ("detail_storeaddress", "Can detail store address"),
            ("enable_storeaddress", "Can enable store address"),
            ("disable_storeaddress", "Can disable store address"),
        )

    def __str__(self):
        return 'StoreAddress'


class StoreCause(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    store = models.ForeignKey(
        Store,
        related_name='store_causes',
        on_delete=models.PROTECT,
        verbose_name=_('store'),
    )
    code = models.CharField(
        unique=True,
        max_length=50,
        verbose_name=_('code'),
    )
    name = models.CharField(
        unique=True,
        max_length=255,
        verbose_name=_('name'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )
    category = models.CharField(
        choices=settings.STORE_ORGANIZATIONTYPE_DEF,
        max_length=3,
        db_index=True,
        verbose_name=_('category'),
    )
    move = models.CharField(
        choices=settings.STORE_MOVE_TYPE,
        max_length=3,
        db_index=True,
        verbose_name=_('move'),
    )
    ddt_required = models.BooleanField(
        db_index=True,
        default=False,
        verbose_name=_('ddt required'),
    )
    invoice_required = models.BooleanField(
        db_index=True, default=False,
        verbose_name=_('invoice required'),
    )
    stock = models.IntegerField(
        choices=settings.STORE_STOCK_BUSY_TYPE,
        db_index=True,
        verbose_name=_('stock'),
    )
    busy = models.IntegerField(
        choices=settings.STORE_STOCK_BUSY_TYPE,
        db_index=True,
        verbose_name=_('busy'),
    )
    default = models.BooleanField(
        default=False,
        verbose_name=_('default'),
    )
    store_document = models.ForeignKey(
        'StoreDocument',
        on_delete=models.PROTECT,
        related_name='store_causes',
        blank=True, null=True,
        verbose_name=_('store document'),
    )
    default_for_shop = models.BooleanField()
    model_template = models.CharField(
        max_length=30,
        blank=True,

    )

    class Meta:
        verbose_name = _('store cause')
        verbose_name_plural = _('store causes')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_storecause", "Can list store cause"),
            ("detail_storecause", "Can detail store cause"),
            ("enable_storecause", "Can enable store cause"),
            ("disable_storecause", "Can disable store cause"),
        )

    def __str__(self):
        return self.name

    def save(self, *args, **kwargs):
        # to set default
        if self.default:
            default_storecauses = StoreCause.objects.filter(
                store=self.store, category=self.category
            ).exclude(
                pk=self.pk
            )
            for store_cause in default_storecauses:
                store_cause.default = False
                store_cause.save()
        super(StoreCause, self).save(*args, **kwargs)


class StoreDocument(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        unique=True,
        max_length=50,
    )
    name = models.CharField(
        unique=True,
        max_length=255,
    )
    description = models.TextField()

    class Meta:
        verbose_name = _('store document')
        verbose_name_plural = _('store documents')
        ordering = ('ordering',)
        permissions = (
            ("list_storedocument", "Can list store document"),
            ("detail_storedocument", "Can detail store document"),
            ("enable_storedocument", "Can enable store document"),
            ("disable_storedocument", "Can disable store document"),
        )

    def __str__(self):
        return self.name


class StoreDocumentNumber(CleanModel, UserModel, DateModel, OrderedModel):
    # TODO: Remove it
    store_document = models.ForeignKey(
        StoreDocument,
        related_name='numbers',
        on_delete=models.PROTECT,
    )
    application = models.CharField(
        max_length=1,
    )
    year = models.IntegerField()
    last_number = models.IntegerField()
    last_date = models.DateField()

    class Meta:
        verbose_name = _('store document number')
        verbose_name_plural = _('store document numbers')
        ordering = ('ordering',)
        permissions = (
            ("list_storedocumentnumber", "Can list store document number"),
            ("detail_storedocumentnumber", "Can detail store document number"),
            ("enable_storedocumentnumber", "Can enable store document number"),
            ("disable_storedocumentnumber", "Can disable store document number"),
        )

    def __str__(self):
        return self.application

==> thx_store-0.1.0-py3-none-any.whl: thx/store/models.py <==
# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _

from thx.address.models import Address, AddressCoordinate
from thx.core.models import UserModel, DateModel, StatusModel, OrderedModel, CleanModel


class Store(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        unique=True,
        max_length=50,
        verbose_name=_('code'),
    )
    name = models.CharField(
        unique=True,
        max_length=255,
        verbose_name=_('name'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )
    default = models.BooleanField(
        default=False,
        verbose_name=_('default'),
    )

    class Meta:
        verbose_name = _('store')
        verbose_name_plural = _('stores')
        ordering = ('ordering',)
        permissions = (
            ("list_store", "Can list store"),
            ("detail_store", "Can detail store"),
            ("enable_store", "Can enable store"),
            ("disable_store", "Can disable store"),
        )

    def __str__(self):
        return self.name


class StoreAddress(Address, AddressCoordinate, CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    store = models.OneToOneField(
        Store,
        related_name='address',
        on_delete=models.PROTECT,
    )

    class Meta:
        verbose_name = _('store address')
        verbose_name_plural = _('store addresses')
        ordering = ('ordering',)
        permissions = (
            ("list_storeaddress", "Can list store address"),
            ("detail_storeaddress", "Can detail store address"),
            ("enable_storeaddress", "Can enable store address"),
            ("disable_storeaddress", "Can disable store address"),
        )

    def __str__(self):
        return (
            f"{self.store.name} - {self.get_address_type_display() if self.get_address_type_display()else ''} "
            f"{self.name} {self.number} {self.locality}"
        )


class StoreCause(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    store = models.ForeignKey(
        Store,
        related_name='store_causes',
        on_delete=models.PROTECT,
        verbose_name=_('store'),
    )
    code = models.CharField(
        unique=True,
        max_length=50,
        verbose_name=_('code'),
    )
    name = models.CharField(
        unique=True,
        max_length=255,
        verbose_name=_('name'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )
    category = models.CharField(
        choices=settings.STORE_ORGANIZATIONTYPE_DEF,
        max_length=3,
        db_index=True,
        verbose_name=_('category'),
    )
    move = models.CharField(
        choices=settings.STORE_MOVE_TYPE,
        max_length=3,
        db_index=True,
        verbose_name=_('move'),
    )
    ddt_required = models.BooleanField(
        db_index=True,
        default=False,
        verbose_name=_('DDT required'),
    )
    invoice_required = models.BooleanField(
        db_index=True, default=False,
        verbose_name=_('invoice required'),
    )
    stock = models.IntegerField(
        choices=settings.STORE_STOCK_BUSY_TYPE,
        db_index=True,
        verbose_name=_('stock'),
    )
    busy = models.IntegerField(
        choices=settings.STORE_STOCK_BUSY_TYPE,
        db_index=True,
        verbose_name=_('busy'),
    )
    default = models.BooleanField(
        default=False,
        verbose_name=_('default'),
    )
    store_document = models.ForeignKey(
        'StoreDocument',
        on_delete=models.PROTECT,
        related_name='store_causes',
        blank=True, null=True,
        verbose_name=_('store document'),
    )
    default_for_shop = models.BooleanField(
        verbose_name=_('default for shop'),
    )

    model_template = models.CharField(
        max_length=30,
        blank=True,
        verbose_name=_('model template'),

    )

    class Meta:
        verbose_name = _('store cause')
        verbose_name_plural = _('store causes')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_storecause", "Can list store cause"),
            ("detail_storecause", "Can detail store cause"),
            ("enable_storecause", "Can enable store cause"),
            ("disable_storecause", "Can disable store cause"),
        )

    def __str__(self):
        return self.name

    def save(self, *args, **kwargs):
        # to set default
        if self.default:
            default_storecauses = StoreCause.objects.filter(
                store=self.store, category=self.category
            ).exclude(
                pk=self.pk
            )
            for store_cause in default_storecauses:
                store_cause.default = False
                store_cause.save()
        super().save(*args, **kwargs)


class StoreDocument(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        unique=True,
        max_length=50,
        verbose_name=_('code'),
    )
    name = models.CharField(
        unique=True,
        max_length=255,
        verbose_name=_('name'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )

    class Meta:
        verbose_name = _('store document')
        verbose_name_plural = _('store documents')
        ordering = ('ordering',)
        permissions = (
            ("list_storedocument", "Can list store document"),
            ("detail_storedocument", "Can detail store document"),
            ("enable_storedocument", "Can enable store document"),
            ("disable_storedocument", "Can disable store document"),
        )

    def __str__(self):
        return self.name


class StoreDocumentNumber(CleanModel, UserModel, DateModel, OrderedModel):
    # TODO: Remove it
    store_document = models.ForeignKey(
        StoreDocument,
        related_name='numbers',
        on_delete=models.PROTECT,
    )
    application = models.CharField(
        max_length=1,
        verbose_name=_('application'),
    )
    year = models.IntegerField(
        verbose_name=_('year'),
    )

    last_number = models.IntegerField(
        verbose_name=_('last number'),
    )

    last_date = models.DateField(
        verbose_name=_('last date'),
    )

    class Meta:
        verbose_name = _('store document number')
        verbose_name_plural = _('store document numbers')
        ordering = ('ordering',)
        permissions = (
            ("list_storedocumentnumber", "Can list store document number"),
            ("detail_storedocumentnumber", "Can detail store document number"),
            ("enable_storedocumentnumber", "Can enable store document number"),
            ("disable_storedocumentnumber", "Can disable store document number"),
        )

    def __str__(self):
        return self.application
